%
% This script generates a normal distribution,
% invokes 'base_analysis' to get mean and its error,
% and plots the points along with mean and one-sigma band.
%

% setup values
P=10;
sigma=2;
N = 100;

% generate the vector of data
V = normrnd(P,sigma,N,1);
% (one could also write an explicit for loop,
%  or use some arrayfun construction; but
%  normrnd already supports making whole blocks).

% call the analysis function
[tval, terr] = base_analysis(V);

% print results
% (here string concatenation is used...)
% Each string in matlab is an array of chars,
% so the rule to concatenate vectors is used,
% namely: v = [v1 v2];
% Here, num2str is also used to convert
% numeric values into strings
disp(['Mean = ' num2str(tval)]);
disp(['Err  = ' num2str(terr)]);
disp(['     (expected ~ ' num2str(sigma/sqrt(N)) ')']);

% plot V and the stat. analysis results:
% 'figure' also returns a figure handle,
% useful, e.g., to export to eps or pdf with sth like:
% print(plothandle,"~/gaussiantest.pdf","-dpdf", ...
%       "-color", "-F:HelveticaBold:20")
% (see also: 'help save')
plothandle=figure;
plot( (1:N), V, 'ro','linewidth',3);
% In 'ro', 'r'=red, 'o'=draw points.
% Also pairs of 'option',value are supported.
% See help for more.
hold on; % means: I'll keep working on this figure.
plot( [1 N], [tval tval], 'b-', 'linewidth',5)
% as before, 'b'=blue and '-'=solid line.
plot( [1 N], [tval tval]-terr, 'b-', 'linewidth',1)
plot( [1 N], [tval tval]+terr, 'b-', 'linewidth',1)
legend('Data','Mean','',''); % must match sequence of curves
xlabel('i');
ylabel('Quantity');
title('Sample gaussian test');
hold off; % I'm done with this figure.

% additional things to do
histhandle=figure;
hist(V);
