% example of usage of 'tau_int_JK.m' to get
% the tau_int from a jackknife analysis.

% files' list
dirname = '../Datafiles/';
filesuffix='.dat';
files={
	'red'
	'green'
	'blue'
};

% setting
MINBINS=20;

% ask the user about which file to inspect
disp('Available files:');
for ifil=1:length(files)
	disp(['   ' num2str(ifil) ' : ' files{ifil}]);
endfor
uchoice = input('Please type your choice of file to analyse for tau_int: ');
uchoice=floor(uchoice);

if (uchoice<1 || uchoice>length(files))
	disp('Invalid choice. Bye.');
	return;
endif

% now proceed: load data, strip off first column,
data = load('-ascii',[dirname files{uchoice} filesuffix]);
data(:,1)=[];
% determine 'large bin size' for the comparison
N = size(data,1);
largeBinSize = floor(N/MINBINS);
if largeBinSize < 2
	error('Cannot compute tau_int: not enough measurements.');
endif
% in this example, the effective mass is chosen as 'Quantity'
%%%this_tau_int = tau_int_JK(data, largeBinSize, @(x) log(x(1)/x(2)));
% (for a primary quantity, e.g., use:
     this_tau_int = tau_int_JK(data, largeBinSize, @(x) x(2));
%  or so.)

% the jackknife estimate of tau_int would have a relative error
% of ~ sqrt(2/Nb), here ~0.316.

printf('\n  ==> For file ''%s'' the tau_int from jackknife is = %.2f +/- %.2f.\n',...
	files{uchoice}, this_tau_int, this_tau_int*sqrt(2/MINBINS));
