function tauint = tau_int_JK(data, binsize, Quantity)
	% estimates the tau_int through jackknife.
	% Calls jackknife with binsize=1 and the provided value,
	% to get naive error and 'realistic' error
	% (resp. Delta and sigma), and computes:
	%     tauint = sigma^2/(2*Delta^2)
	% (one gets in principle a plateau in tau_int_JK(binsize)
	%  that should stabilise at the 'real' tau_int,
	%  except cases with slow modes, too short whole sequence, etc.)

	% The two calls to jackknife are now made. Only the
	% second returned value is useful here, so the first
	% gets discarded:
	[~, err_sigma]  = jackknife(data, binsize, Quantity);
	[~, err_Delta]  = jackknife(data,       1, Quantity);
	
	tauint = 0.5*((err_sigma/err_Delta)^2);

endfunction
